@@ -185,6 +185,8 @@ pub struct TransactionStatusMeta {
     pub pre_token_balances: Option<Vec<TransactionTokenBalance>>,
     #[serde(deserialize_with = "default_on_eof")]
     pub post_token_balances: Option<Vec<TransactionTokenBalance>>,
+    #[serde(deserialize_with = "default_on_eof")]
+    pub rewards: Option<Rewards>,
 }
 
 impl Default for TransactionStatusMeta {
@@ -198,6 +200,7 @@ impl Default for TransactionStatusMeta {
             log_messages: None,
             pre_token_balances: None,
             post_token_balances: None,
+            rewards: None,
         }
     }
 }
@@ -215,6 +218,7 @@ pub struct UiTransactionStatusMeta {
     pub log_messages: Option<Vec<String>>,
     pub pre_token_balances: Option<Vec<UiTransactionTokenBalance>>,
     pub post_token_balances: Option<Vec<UiTransactionTokenBalance>>,
+    pub rewards: Option<Rewards>,
 }
 
 impl UiTransactionStatusMeta {
@@ -237,6 +241,7 @@ impl UiTransactionStatusMeta {
             post_token_balances: meta
                 .post_token_balances
                 .map(|balance| balance.into_iter().map(|balance| balance.into()).collect()),
+            rewards: meta.rewards,
         }
     }
 }
@@ -259,6 +264,7 @@ impl From<TransactionStatusMeta> for UiTransactionStatusMeta {
             post_token_balances: meta
                 .post_token_balances
                 .map(|balance| balance.into_iter().map(|balance| balance.into()).collect()),
+            rewards: meta.rewards,
         }
     }
 }
@@ -346,6 +352,7 @@ pub struct ConfirmedBlock {
     pub transactions: Vec<TransactionWithStatusMeta>,
     pub rewards: Rewards,
     pub block_time: Option<UnixTimestamp>,
+    pub block_height: Option<u64>,
 }
 
 impl ConfirmedBlock {
@@ -361,6 +368,7 @@ impl ConfirmedBlock {
                 .collect(),
             rewards: self.rewards,
             block_time: self.block_time,
+            block_height: self.block_height,
         }
     }
 
@@ -403,6 +411,7 @@ impl ConfirmedBlock {
                 None
             },
             block_time: self.block_time,
+            block_height: self.block_height,
         }
     }
 }
@@ -416,6 +425,7 @@ pub struct EncodedConfirmedBlock {
     pub transactions: Vec<EncodedTransactionWithStatusMeta>,
     pub rewards: Rewards,
     pub block_time: Option<UnixTimestamp>,
+    pub block_height: Option<u64>,
 }
 
 #[derive(Debug, PartialEq, Serialize, Deserialize)]
@@ -431,6 +441,7 @@ pub struct UiConfirmedBlock {
     #[serde(default, skip_serializing_if = "Option::is_none")]
     pub rewards: Option<Rewards>,
     pub block_time: Option<UnixTimestamp>,
+    pub block_height: Option<u64>,
 }
 
 impl From<EncodedConfirmedBlock> for UiConfirmedBlock {
@@ -443,6 +454,7 @@ impl From<EncodedConfirmedBlock> for UiConfirmedBlock {
             signatures: None,
             rewards: Some(block.rewards),
             block_time: block.block_time,
+            block_height: block.block_height,
         }
     }
 }
@@ -456,6 +468,7 @@ impl From<UiConfirmedBlock> for EncodedConfirmedBlock {
             transactions: block.transactions.unwrap_or_default(),
             rewards: block.rewards.unwrap_or_default(),
             block_time: block.block_time,
+            block_height: block.block_height,
         }
     }
 }
